@@ -1,4 +1,4 @@
-/* $Id: memobj-r0drv.cpp 135976 2020-02-04 10:35:17Z bird $ */
+/* $Id: memobj-r0drv.cpp 144317 2021-05-11 12:20:49Z aeichner $ */
 /** @file
  * IPRT - Ring-0 Memory Objects, Common Code.
  */
@@ -358,6 +358,10 @@ RTR0DECL(int) RTR0MemObjFree(RTR0MEMOBJ MemObj, bool fFreeMappings)
                 pMem->uRel.Parent.papMappings[pMem->uRel.Parent.cMappings++] = pChild;
                 return rc;
             }
+
+            pChild->u32Magic++;
+            pChild->enmType = RTR0MEMOBJTYPE_END;
+            RTMemFree(pChild);
         }
     }
 
